pub enum RuneError {
RingTooSmall,
SignerIndexOutOfRange,
InconsistentRingParameter,
MalformedSignature,
MalformedChallenge,
MalformedPublicKey,
RejectionSamplingFailed,
}Expand description
Errors returned by Rune key, signing, and verification operations.
Variants
RingTooSmall
Ring size is less than 2.
SignerIndexOutOfRange
Signer index is out of range for the given ring.
InconsistentRingParameter
Not all public keys in the ring share the same public matrix seed.
MalformedSignature
A signature field has wrong length or structure.
MalformedChallenge
A supplied challenge polynomial has invalid weight or coefficients.
MalformedPublicKey
A public key has invalid structure.
RejectionSamplingFailed
Rejection sampling did not terminate within the maximum number of attempts.