Rune ring signatures.
rune-ring authenticates messages while hiding which member of a public
key ring produced the signature.
Re-exports
pub use core::ring_sign;pub use core::ring_verify;pub use core::RingSignature;pub use error::RuneError;pub use keys::keygen;pub use keys::PublicKey;pub use keys::SecretKey;pub use params::Params;pub use params::RUNE_128;pub use params::RUNE_256;
Modules
- core
- Ring signing and verification.
- error
- Error type for Rune operations.
- keys
- Key generation for Rune.
- params
- Cryptographic parameter sets for Rune.
Structs
- Poly
- A polynomial in
R_q = Z_q[X]/(X^n + 1), stored as a centered coefficient vector for the active parameter set.